@@ -7,6 +7,7 @@ from .util import (
     convert_from_hex,
     convert_to_hex,
 )
+from .const import RIOT_FLAGS_CLOCK_ON, RIOT_FLAGS_CLOCK_24_HOUR
 from .shadow_client_subscriber import ShadowClientSubscriberMixin
 
 _LOGGER = logging.getLogger(__name__)
@@ -28,7 +29,7 @@ class RestIot(ShadowClientSubscriberMixin):
     blue: int = 0
     white: int = 0
     brightness: int = 0
-    charging_status: int = None #Expected values: 0= Not Charging, 3= Charging, plugged in, 5= Charging, on base 
+    charging_status: int = None  # Expected values: 0= Not Charging, 3= Charging, plugged in, 5= Charging, on base
     clock: int = None
     flags: int = None
     toddler_lock: bool = False
@@ -41,11 +42,15 @@ class RestIot(ShadowClientSubscriberMixin):
         if safely_get_json_value(state, "deviceInfo.b") is not None:
             self.battery_level = safely_get_json_value(state, "deviceInfo.b", int)
         if safely_get_json_value(state, "deviceInfo.powerStatus") is not None:
-            self.charging_status = safely_get_json_value(state, "deviceInfo.powerStatus", int)
+            self.charging_status = safely_get_json_value(
+                state, "deviceInfo.powerStatus", int
+            )
         if safely_get_json_value(state, "toddlerLockOn") is not None:
             self.toddler_lock = safely_get_json_value(state, "toddlerLockOn", bool)
         if safely_get_json_value(state, "toddlerLock.turnOnMode") is not None:
-            self.toddler_lock_mode = safely_get_json_value(state, "toddlerLock.turnOnMode", str)
+            self.toddler_lock_mode = safely_get_json_value(
+                state, "toddlerLock.turnOnMode", str
+            )
         if safely_get_json_value(state, "current.playing") is not None:
             self.current_playing = safely_get_json_value(state, "current.playing")
         if safely_get_json_value(state, "connected") is not None:
@@ -81,7 +86,8 @@ class RestIot(ShadowClientSubscriberMixin):
                 safely_get_json_value(state, "clock.i", int)
             )
         if safely_get_json_value(state, "clock.flags") is not None:
-            self.flags = safely_get_json_value(state, "clock.flags", int)    
+            self.flags = safely_get_json_value(state, "clock.flags", int)
+
         _LOGGER.debug(f"new state:{self}")
         self.publish_updates()
 
@@ -104,8 +110,10 @@ class RestIot(ShadowClientSubscriberMixin):
             "charging_status": self.charging_status,
             "clock": self.clock,
             "flags": self.flags,
-            "toddler_lock": self.toddler_lock, 
-            "toddler_lock_mode": self.toddler_lock_mode, 
+            "is_clock_on": self.is_clock_on,
+            "is_clock_24h": self.is_clock_24h,
+            "toddler_lock": self.toddler_lock,
+            "toddler_lock_mode": self.toddler_lock_mode,
         }
 
     def __str__(self):
@@ -122,10 +130,14 @@ class RestIot(ShadowClientSubscriberMixin):
     @property
     def is_playing(self):
         return self.sound_id != 19998
-    
+
     @property
     def is_clock_on(self):
-        return self.flags != 0
+        return self.flags is not None and self.flags & RIOT_FLAGS_CLOCK_ON
+
+    @property
+    def is_clock_24h(self):
+        return self.flags is not None and self.flags & RIOT_FLAGS_CLOCK_24_HOUR
 
     def favorite_names(self, active_only: bool = True):
         names = []
@@ -148,11 +160,13 @@ class RestIot(ShadowClientSubscriberMixin):
 
     def set_clock(self, brightness: int = 0):
         _LOGGER.debug(f"Setting clock on: {brightness}")
-        self._update({"clock": {"flags": 32768, "i": convert_from_percentage(brightness)}})
+        self._update(
+            {"clock": {"flags": self.flags | RIOT_FLAGS_CLOCK_ON, "i": convert_from_percentage(brightness)}}
+        )
 
     def turn_clock_off(self):
         _LOGGER.debug(f"Turn off clock")
-        self._update({"clock": {"flags": 0, "i": 655}})
+        self._update({"clock": {"flags": self.flags ^ RIOT_FLAGS_CLOCK_ON, "i": 655}})
 
     # favorite_name_id is expected to be a string of name-id since name alone isn't unique
     def set_favorite(self, favorite_name_id: str):
@@ -167,23 +181,39 @@ class RestIot(ShadowClientSubscriberMixin):
     def turn_light_off(self):
         _LOGGER.debug(f"Turning light off")
         # 9999 = custom color 9998 = turn off
-        self._update(
-            {
-                "current": {
-                    "color": {
-                        "id": 9998
+        # if favorite is playing then light can be turned off without turning off sound
+        if self.current_playing == "routine":
+            self._update(
+                {
+                    "current": {
+                        "color": {
+                            "id": 9998,
+                            "r": 0,
+                            "g": 0,
+                            "b": 0,
+                            "w": 0,
+                        }
                     }
                 }
-            }
-        )
+            )
+        if self.current_playing == "remote":
+            self._update(
+                {
+                    "current": {
+                        "playing": "none",
+                        "color": {
+                            "id": 9998,
+                            "r": 0,
+                            "g": 0,
+                            "b": 0,
+                            "w": 0,
+                        },
+                    }
+                }
+            )
 
     def set_color(
-        self,
-        red: int,
-        green: int,
-        blue: int,
-        white: int = 0,
-        brightness: int = 0
+        self, red: int, green: int, blue: int, white: int = 0, brightness: int = 0
     ):
         # 9999 = custom color 9998 = turn off
         new_color_id: int = 9999
@@ -205,7 +235,7 @@ class RestIot(ShadowClientSubscriberMixin):
                             "b": convert_from_hex(blue),
                             "i": convert_from_percentage(brightness),
                             "w": white,
-                        }
+                        },
                     }
                 }
             )
